@@ -192,10 +192,30 @@ namespace dmr {
     MpvGLWidget::~MpvGLWidget() 
     {
         makeCurrent();
-        delete _darkTex;
-        delete _lightTex;
+        if (_darkTex) {
+            _darkTex->destroy();
+            delete _darkTex;
+        }
+        if (_lightTex) {
+            _lightTex->destroy();
+            delete _lightTex;
+        }
+
+        for (auto mask: _cornerMasks) {
+            if (mask) mask->destroy();
+        }
+
         _vbo.destroy();
+
+        for (int i = 0; i < 4; i++) {
+            _vboCorners[i].destroy();
+        }
+
         _vao.destroy();
+        _vaoBlend.destroy();
+        _vaoCorner.destroy();
+
+        if (_fbo) delete _fbo;
 
         if (_gl_ctx)
             mpv_opengl_cb_set_update_callback(_gl_ctx, NULL, NULL);
@@ -310,15 +330,18 @@ namespace dmr {
         setupIdlePipe();
         setupBlendPipe();
 
+#ifdef _LIBDMR_
+        toggleRoundedClip(false);
+#else
 #ifndef USE_DXCB
         connect(window()->windowHandle(), &QWindow::windowStateChanged, [=]() {
             auto top = this->topLevelWidget();
             bool rounded = !top->isFullScreen() && !top->isMaximized();
             toggleRoundedClip(rounded);
         });
+#endif
 #endif
 
-        //if (mpv_opengl_cb_init_gl(_gl_ctx, NULL, get_proc_address, NULL) < 0)
         if (mpv_opengl_cb_init_gl(_gl_ctx, "GL_MP_MPGetNativeDisplay", get_proc_address, NULL) < 0)
             throw std::runtime_error("could not initialize OpenGL");
     }
@@ -327,11 +350,16 @@ namespace dmr {
     {
         if (!_doRoundedClipping) return;
 
+        auto desiredSize = size() * qApp->devicePixelRatio();
+
         if (_fbo) {
+            if (_fbo->size() == desiredSize) {
+                return;
+            }
             _fbo->release();
             delete _fbo;
         }
-        _fbo = new QOpenGLFramebufferObject(size() * qApp->devicePixelRatio());
+        _fbo = new QOpenGLFramebufferObject(desiredSize);
     }
 
     void MpvGLWidget::updateCornerMasks()
@@ -517,13 +545,10 @@ namespace dmr {
     {
         QOpenGLFunctions *f = QOpenGLContext::currentContext()->functions();
 
-        if (_playing) {
-            updateMovieFbo();
-        } else {
-            updateVbo();
-            if (_doRoundedClipping)
-                updateVboCorners();
-        }
+        updateMovieFbo();
+        updateVbo();
+        if (_doRoundedClipping)
+            updateVboCorners();
 
         qDebug() << "GL resize" << w << h;
         QOpenGLWidget::resizeGL(w, h);
@@ -566,7 +591,7 @@ namespace dmr {
                     _glProgBlend->release();
                 }
 
-                if (_doRoundedClipping) {
+                {
                     f->glBlendFunc(GL_SRC_ALPHA, GL_ZERO);
                     // blend corners
                     //QOpenGLVertexArrayObject::Binder vaoBind(&_vaoCorner);
@@ -674,6 +699,7 @@ namespace dmr {
         }
         updateVbo();
         updateVboCorners();
+        updateMovieFbo();
         update();
     }
 
