@@ -5,7 +5,7 @@
         <location filename="../main.cpp" line="88"/>
         <location filename="../main.cpp" line="120"/>
         <source>Deepin Movie</source>
-        <translation>Películes Deepin</translation>
+        <translation>Deepin Movie</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="89"/>
@@ -15,7 +15,7 @@
     <message>
         <location filename="../common/mainwindow.cpp" line="116"/>
         <source>Invalid folder</source>
-        <translation>Carpeta non válida</translation>
+        <translation>La carpeta nun ye válida</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="130"/>
@@ -45,7 +45,7 @@
     <message>
         <location filename="../common/settings_translation.cpp" line="8"/>
         <source>Open a new player for each file played</source>
-        <translation type="unfinished"/>
+        <translation>Abrir una ventana nueva por cada ficheru que se reproduza</translation>
     </message>
     <message>
         <location filename="../common/settings_translation.cpp" line="9"/>
@@ -107,7 +107,7 @@
     <message>
         <location filename="../common/settings_translation.cpp" line="22"/>
         <source>Font Style</source>
-        <translation type="unfinished"/>
+        <translation>Estilu de la fonte</translation>
     </message>
     <message>
         <location filename="../common/settings_translation.cpp" line="23"/>
@@ -117,7 +117,7 @@
     <message>
         <location filename="../common/settings_translation.cpp" line="24"/>
         <source>Open file</source>
-        <translation>Abrir ficheru</translation>
+        <translation>Abrir un ficheru</translation>
     </message>
     <message>
         <location filename="../common/settings_translation.cpp" line="25"/>
@@ -227,7 +227,7 @@
     <message>
         <location filename="../common/settings_translation.cpp" line="46"/>
         <source>Font Size</source>
-        <translation type="unfinished"/>
+        <translation>Tamañu de la fonte</translation>
     </message>
 </context>
 <context>
@@ -254,7 +254,7 @@
         <location filename="../common/actions.cpp" line="82"/>
         <location filename="../common/actions.cpp" line="102"/>
         <source>Open File</source>
-        <translation type="unfinished"/>
+        <translation>Abrir un ficheru</translation>
     </message>
     <message>
         <location filename="../common/actions.cpp" line="84"/>
@@ -286,17 +286,17 @@
         <location filename="../common/actions.cpp" line="83"/>
         <location filename="../common/actions.cpp" line="103"/>
         <source>Open Folder</source>
-        <translation>Abrir carpeta</translation>
+        <translation>Abrir una carpeta</translation>
     </message>
     <message>
         <location filename="../common/actions.cpp" line="104"/>
         <source>Open URL</source>
-        <translation>Abrir URL</translation>
+        <translation>Abrir una URL</translation>
     </message>
     <message>
         <location filename="../common/actions.cpp" line="105"/>
         <source>Open CD/DVD</source>
-        <translation>Abrir CD/DVD</translation>
+        <translation>Abrir un CD/DVD</translation>
     </message>
     <message>
         <location filename="../common/actions.cpp" line="109"/>
@@ -516,20 +516,20 @@
     <message>
         <location filename="../common/mainwindow.cpp" line="1417"/>
         <source>Open Folder</source>
-        <translation>Abrir carpeta</translation>
+        <translation>Abrir una carpeta</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="1432"/>
         <location filename="../common/mainwindow.cpp" line="1449"/>
         <location filename="../common/mainwindow.cpp" line="1784"/>
         <source>Open File</source>
-        <translation type="unfinished"/>
+        <translation>Abrir un ficheru</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="1434"/>
         <location filename="../common/mainwindow.cpp" line="1451"/>
         <source>All videos (%1)</source>
-        <translation type="unfinished"/>
+        <translation>Tolos vídeos (%1)</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="1652"/>
@@ -627,7 +627,7 @@
     <message>
         <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
         <source>Duration:</source>
-        <translation>Duración</translation>
+        <translation>Duración:</translation>
     </message>
     <message>
         <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
